package shapesbackup;

/**
 * The Triangle class definition.
 * Implements method draw() which is abstract in class Shape.
 * Sets and maintains length of the three sides for the triangle.
 *
 * @author Prof. Carl B. Struck
 * @version Copyright (c) 2008 -- SCCC West
 */

public final class Triangle extends Shape
{
    private int side1;
    private int side2;
    private int side3;
    
    /**
     * Constructor passes default values to 
     * Triangle(int, int, int, int, int) constructor.
     */
    public Triangle()
    {
        this(0, 0, 0, 0, 0);
    }
    
    /**
     * Constructor sets length of the three sides of the triangle
     * and passes the point where it will draw to the Shape
     * superclass constructor.
     * 
     * @param x the x-coordinate where the triangle draws
     * @param y the y-coordinate where the triangle draws
     * @param side1 the length of side 1 of the triangle
     * @param side2 the length of side 2 of the triangle
     * @param side3 the length of side 3 of the triangle
     */      
    public Triangle(int x, int y, int side1, int side2, int side3)
    {
        super(x, y);
        setSide1(side1);
        setSide2(side2);
        setSide3(side3);
    }
    
    /**
     * Sets the length of side 1 of the triangle which must be
     * greater than zero (0) or equal to zero if null (default).

     * @param side1 the length of side 1 of the triangle 
     */
    public void setSide1(int side1)
    {
        if (side1 >= 0)
        {
            this.side1 = side1;
        }
    }

    /**
     * Sets the length of side 2 of the triangle which must be
     * greater than zero (0) or equal to zero if null (default).
     * 
     * @param side2 the length of side 2 of the triangle 
     */
    public void setSide2(int side2)
    {
        if (side2 >= 0)
        {
            this.side2 = side2;
        }
    }

    /**
     * Sets the length of side 3 of the triangle which must be
     * greater than zero (0) or equal to zero if null (default).
     * 
     * @param side3 the length of side 3 of the triangle 
     */
    public void setSide3(int side3)
    {
        if (side3 >= 0)
        {
            this.side3 = side3;
        }
    }
    
    /**
     * Returns the length of side 1 of the triangle.
     * 
     * @return the length of side 1 of the triangle 
     */
    public int getSide1()
    {
        return side1;
    }
    
    /**
     * Returns the length of side 2 of the triangle.
     * 
     * @return the length of side 2 of the triangle 
     */
    public int getSide2()
    {
        return side2;
    }
    
    /** Returns the length of side 3 of the triangle.
     * 
     * @return the length of side 3 of the triangle 
     */
    public int getSide3()
    {
        return side3;
    }
    
    /**
     * Prints the length of the three sides of the triangle
     * to the terminal window.
     */
    @Override
    public void draw()
    {
        System.out.print("Draw triangle with sides "
            + getSide1() + " by "
            + getSide2() + " by "
            + getSide3() );
    }
}

