package studenttuition;

/**
 * The NYStateResident class definition which manages student tuition field.
 *
 * @author Carl B. Struck
 * @version Copyright 2002 (c) SCCC West
 */
public final class NYStateResident extends Student implements Tuition
{
    String county;

    /**
     * Constructor sets default values for student first name, last name, grade,
     * credits and county residence fields.
     */
    public NYStateResident()
    {
        this("", "", "", 0, "");
    }

    /**
     * Explicit call to superclass Student constructor sets initial values for
     * the student first name, last name, grade and credits, and then
     * sets the county residence field.
     *
     * @param firstName the student's first name
     * @param lastName the student's last name
     * @param grade the student's letter grade
     * @param credits the number of credits carried by the student
     * @param county the student's county of residence
     */
    public NYStateResident(String firstName, String lastName, String grade, 
            int credits, String county)
    {
        super(firstName, lastName, grade, credits);
        setCounty(county);
    }

    /**
     * Updates the student's county of residence in New York State.
     *
     * @param county the student's county of residence in New York State
     */
    public void setCounty(String county)
    {
        this.county = county;
    }

    /**
     * Returns the student's county of residence in New York State.
     *
     * @return the student's county of residence in New York State.
     */
    public String getCounty()
    {
        return county;
    }

    /**
     * Returns the semester tuition for a student as an int based on number of
     * credits. If credits from superclass Student are less than 12, multiply
     * credits by the part-time tuition rate; otherwise tuition is set to the
     * flat full-time rate. This method must be implemented because the
     * SuffolkResident implements the Tuition interface which defines the
     * abstract getTuition() method.
     *
     * @return The student's tuition
     */
    @Override
    public int getTuition()
    {
        if (getCredits() < 12)
        {
            return (PT_TUITION * getCredits());
        } else
        {
            return FT_TUITION;
        }
    }

    /**
     * Returns the tuition which must be paid by Nassau County as an int value.
     *
     * @return Student's NYS tuition
     */
    public int getNYStateTuition()
    {
        return getTuition();
    }

    /**
     * Returns the formatted semester tuition and Nassau tuition fields with
     * labels as a string. This method must be implemented because class
     * NYStateResident extends the Student class which defines abstract
     * getTuitionString() method.
     *
     * @return Formatted semester tuition and Nassau tuition values with labels
     * as a string
     */
    @Override
    public String getTuitionString()
    {
        return "Tuition: $" + getTuition()
                + "\nTuition billed to " + getCounty() 
                + " County: $" + getNYStateTuition();
    }
}
